@@ -2,14 +2,22 @@
 One-hot variational autoregressive models for multiple categorical choices beyond binary
 """
 
+from typing import Any, Optional, Tuple, Union, List
 import tensorflow as tf
+from tensorflow.keras.layers import Layer
+from tensorflow.keras.models import Model
 import numpy as np
 
-# TODO(@refraction-ray): Add type annotation in this module some time.
 
-
-class MaskedLinear(tf.keras.layers.Layer):
-    def __init__(self, input_space, output_space, spin_channel, mask=None, dtype=None):
+class MaskedLinear(Layer):  # type: ignore
+    def __init__(
+        self,
+        input_space: int,
+        output_space: int,
+        spin_channel: int,
+        mask: Optional[tf.Tensor] = None,
+        dtype: Optional[tf.DType] = None,
+    ):
         super().__init__()
         if dtype is None:
             self._dtype = tf.float32
@@ -38,36 +46,36 @@ class MaskedLinear(tf.keras.layers.Layer):
         else:
             self.mask = tf.ones([output_space, spin_channel, input_space, spin_channel])
 
-    def call(self, inputs):
+    def call(self, inputs: tf.Tensor) -> tf.Tensor:
         w_mask = tf.multiply(self.mask, self.w)
         return tf.tensordot(inputs, w_mask, axes=[[-2, -1], [2, 3]]) + self.b
 
-    def regularization(self, lbd_w=1.0, lbd_b=1.0):
+    def regularization(self, lbd_w: float = 1.0, lbd_b: float = 1.0) -> tf.Tensor:
         return lbd_w * tf.reduce_sum(self.w**2) + lbd_b * tf.reduce_sum(self.b**2)
 
 
-class MADE(tf.keras.Model):
+class MADE(Model):  # type: ignore
     def __init__(
         self,
-        input_space,
-        output_space,
-        hidden_space,
-        spin_channel,
-        depth,
-        evenly=True,
-        dtype=None,
-        activation=None,
-        nonmerge=True,
-        probamp=None,
+        input_space: int,
+        output_space: int,
+        hidden_space: int,
+        spin_channel: int,
+        depth: int,
+        evenly: bool = True,
+        dtype: Optional[tf.DType] = None,
+        activation: Optional[Any] = None,
+        nonmerge: bool = True,
+        probamp: Optional[tf.Tensor] = None,
     ):
         super().__init__()
         if not dtype:
             self._dtype = tf.float32
         else:
             self._dtype = dtype
-        self._m = []
-        self._masks = []
-        self.ml_layer = []
+        self._m: List[np.array] = []  # type: ignore
+        self._masks: List[tf.Tensor] = []
+        self.ml_layer: List[Any] = []
         self.input_space = input_space
         self.spin_channel = spin_channel
         self._build_masks(
@@ -84,8 +92,14 @@ class MADE(tf.keras.Model):
         self.probamp = probamp
 
     def _build_masks(
-        self, input_space, output_space, hidden_space, spin_channel, depth, evenly
-    ):
+        self,
+        input_space: int,
+        output_space: int,
+        hidden_space: int,
+        spin_channel: int,
+        depth: int,
+        evenly: bool,
+    ) -> None:
         self._m.append(np.arange(1, input_space + 1))
         for i in range(1, depth + 1):
             if i == depth:  # the last layer
@@ -111,10 +125,10 @@ class MADE(tf.keras.Model):
                 else:
                     self._m.append(np.random.randint(1, input_space, size=hidden_space))
             if i == depth:
-                mask = self._m[i][None, :] > self._m[i - 1][:, None]
+                mask = self._m[i][None, :] > self._m[i - 1][:, None]  # type: ignore
             else:
                 # input to hidden & hidden to hidden
-                mask = self._m[i][None, :] >= self._m[i - 1][:, None]
+                mask = self._m[i][None, :] >= self._m[i - 1][:, None]  # type: ignore
             # add two spin channel axis into mask
             mask = mask.T
             mask = mask[:, np.newaxis, :, np.newaxis]
@@ -162,10 +176,10 @@ class MADE(tf.keras.Model):
                     )
                 )
 
-    def _check_masks(self):
+    def _check_masks(self) -> None:
         pass
 
-    def call(self, inputs):
+    def call(self, inputs: tf.Tensor) -> tf.Tensor:
         if self.nonmerge:
             nonmerge_block = tf.roll(inputs, axis=-2, shift=1) * -10.0
             # PBC here
@@ -181,17 +195,17 @@ class MADE(tf.keras.Model):
         outputs = tf.keras.layers.Softmax()(inputs)
         return outputs
 
-    def model(self):
+    def model(self) -> Any:
         x = tf.keras.layers.Input(shape=(self.input_space, self.spin_channel))
         return tf.keras.Model(inputs=[x], outputs=self.call(x))
 
-    def regularization(self, lbd_w=1.0, lbd_b=1.0):
+    def regularization(self, lbd_w: float = 1.0, lbd_b: float = 1.0) -> tf.Tensor:
         loss = 0.0
         for l in self.ml_layer:
             loss += l.regularization(lbd_w=lbd_w, lbd_b=lbd_b)
         return loss
 
-    def sample(self, batch_size):
+    def sample(self, batch_size: int) -> Tuple[np.array, tf.Tensor]:  # type: ignore
         eps = 1e-10
         sample = np.zeros(
             [batch_size, self.input_space, self.spin_channel], dtype=np.float32
@@ -212,28 +226,27 @@ class MADE(tf.keras.Model):
 
         return sample, x_hat
 
-    def _log_prob(self, sample, x_hat):
+    def _log_prob(self, sample: tf.Tensor, x_hat: tf.Tensor) -> tf.Tensor:
         eps = 1e-10
         probm = tf.multiply(x_hat, sample)
         probm = tf.reduce_sum(probm, axis=-1)
         lnprobm = tf.math.log(probm + eps)
         return tf.reduce_sum(lnprobm, axis=-1)
 
-    def log_prob(self, sample):
+    def log_prob(self, sample: tf.Tensor) -> tf.Tensor:
         x_hat = self.call(sample)
         log_prob = self._log_prob(sample, x_hat)
-
         return log_prob
 
 
-class MaskedConv2D(tf.keras.layers.Layer):
-    def __init__(self, mask_type, **kwargs):
+class MaskedConv2D(Layer):  # type: ignore
+    def __init__(self, mask_type: str, **kwargs: Any):
         super().__init__()
         assert mask_type in {"A", "B"}, "mask_type must be in A or B"
         self.mask_type = mask_type
         self.conv = tf.keras.layers.Conv2D(**kwargs)
 
-    def build(self, input_shape):
+    def build(self, input_shape: Union[List[tf.TensorShape], tf.TensorShape]) -> None:
         # Build the conv2d layer to initialize kernel variables
         self.conv.build(input_shape)
         # Use the initialized kernel to create the mask
@@ -247,26 +260,26 @@ class MaskedConv2D(tf.keras.layers.Layer):
         if self.mask_type == "B":
             self.mask[kernel_shape[0] // 2, kernel_shape[1] // 2, ...] = 1.0
 
-    def call(self, inputs):
+    def call(self, inputs: tf.Tensor) -> tf.Tensor:
         self.conv.kernel = self.kernel * self.mask
         self.conv.bias = self.bias
         return self.conv(inputs)
 
 
-class ResidualBlock(tf.keras.layers.Layer):
-    def __init__(self, layers):
+class ResidualBlock(Layer):  # type: ignore
+    def __init__(self, layers: List[Any]):
         super().__init__()
         self.layers = layers
 
-    def call(self, inputs):
+    def call(self, inputs: tf.Tensor) -> tf.Tensor:
         y = inputs
         for layer in self.layers:
             y = layer(y)
         return y + inputs
 
 
-class PixelCNN(tf.keras.Model):
-    def __init__(self, spin_channel, depth, filters):
+class PixelCNN(Model):  # type: ignore
+    def __init__(self, spin_channel: int, depth: int, filters: int):
         super().__init__()
         self.rb = []
         self.rb0 = MaskedConv2D(
@@ -294,7 +307,7 @@ class PixelCNN(tf.keras.Model):
         self.depth = depth
         self.spin_channel = spin_channel
 
-    def call(self, inputs):
+    def call(self, inputs: tf.Tensor) -> tf.Tensor:
         x = self.rb0(inputs)
         x = self.relu(x)
         for i in range(self.depth - 1):
@@ -303,7 +316,7 @@ class PixelCNN(tf.keras.Model):
         x = tf.keras.layers.Softmax(axis=-1)(x)
         return x
 
-    def sample(self, batch_size, h, w):
+    def sample(self, batch_size: int, h: int, w: int) -> Tuple[np.array, tf.Tensor]:  # type: ignore
         eps = 1e-10
         sample = np.zeros([batch_size, h, w, self.spin_channel], dtype=np.float32)
         for i in range(h):
@@ -320,23 +333,27 @@ class PixelCNN(tf.keras.Model):
 
         return sample, x_hat
 
-    def _log_prob(self, sample, x_hat):
+    def _log_prob(self, sample: tf.Tensor, x_hat: tf.Tensor) -> tf.Tensor:
         eps = 1e-10
         probm = tf.multiply(x_hat, sample)
         probm = tf.reduce_sum(probm, axis=-1)
         lnprobm = tf.math.log(probm + eps)
-
         return tf.reduce_sum(lnprobm, axis=[-1, -2])
 
-    def log_prob(self, sample):
+    def log_prob(self, sample: tf.Tensor) -> tf.Tensor:
         x_hat = self.call(sample)
         log_prob = self._log_prob(sample, x_hat)
-
         return log_prob
 
 
-class NMF(tf.keras.Model):
-    def __init__(self, spin_channel, *dimensions, _dtype=tf.float32, probamp=None):
+class NMF(Model):  # type: ignore
+    def __init__(
+        self,
+        spin_channel: int,
+        *dimensions: int,
+        _dtype: tf.DType = tf.float32,
+        probamp: Optional[tf.Tensor] = None
+    ):
         super().__init__()
         self.w = self.add_weight(
             name="meanfield-parameter",
@@ -351,14 +368,14 @@ class NMF(tf.keras.Model):
         self.spin_channel = spin_channel
         self.probamp = probamp
 
-    def call(self, inputs=None):
+    def call(self, inputs: Optional[tf.Tensor] = None) -> tf.Tensor:
         # x = tf.keras.layers.Softmax(axis=-1)(self.w)
         if self.probamp is None:
             return self.w
         else:
             return self.w + self.probamp
 
-    def sample(self, batch_size):
+    def sample(self, batch_size: int) -> Tuple[tf.Tensor, tf.Tensor]:
         x_hat = self.call()
         x_hat = x_hat[tf.newaxis, :]
         tile_shape = tuple([batch_size] + [1 for _ in range(self.D + 1)])
@@ -374,16 +391,14 @@ class NMF(tf.keras.Model):
         x_hat = tf.keras.layers.Softmax(axis=-1)(x_hat)
         return sample, x_hat
 
-    def _log_prob(self, sample, x_hat):
+    def _log_prob(self, sample: tf.Tensor, x_hat: tf.Tensor) -> tf.Tensor:
         eps = 1e-10
         probm = tf.multiply(x_hat, sample)
         probm = tf.reduce_sum(probm, axis=-1)
         lnprobm = tf.math.log(probm + eps)
-
         return tf.reduce_sum(lnprobm, axis=[-i - 1 for i in range(self.D)])
 
-    def log_prob(self, sample):
+    def log_prob(self, sample: tf.Tensor) -> tf.Tensor:
         x_hat = self.call(sample)
         log_prob = self._log_prob(sample, x_hat)
-
         return log_prob
