@@ -13,7 +13,7 @@ import tensornetwork as tn
 from scipy.stats import unitary_group
 
 from .cons import backend, dtypestr, npdtype
-from .backends import get_backend  # type: ignore
+from .backends import get_backend
 from .utils import arg_alias
 
 thismodule = sys.modules[__name__]
@@ -478,6 +478,7 @@ def phase_gate(theta: float = 0) -> Gate:
     :return: phase gate
     :rtype: Gate
     """
+    theta = array_to_tensor(theta)
     i00, i11 = array_to_tensor(np.array([[1, 0], [0, 0]]), np.array([[0, 0], [0, 1]]))
     unitary = i00 + backend.exp(1.0j * theta) * i11
     return Gate(unitary)
@@ -527,6 +528,7 @@ def u_gate(theta: float = 0, phi: float = 0, lbd: float = 0) -> Gate:
     :return: _description_
     :rtype: Gate
     """
+    theta, phi, lbd = array_to_tensor(theta, phi, lbd)
     i00, i01, i10, i11 = array_to_tensor(
         np.array([[1, 0], [0, 0]]),
         np.array([[0, 1], [0, 0]]),
@@ -675,9 +677,8 @@ def random_single_qubit_gate() -> Gate:
     :rtype: Gate
     """
     # Get the random parameters
-    theta, alpha, phi = np.random.rand(3) * 2 * np.pi  # type: ignore
-
-    return r_gate(theta, alpha, phi)  # type: ignore
+    theta, alpha, phi = np.random.rand(3) * 2 * np.pi
+    return r_gate(theta, alpha, phi)
 
 
 # rs = random_single_qubit_gate  # deprecated
