@@ -37,7 +37,7 @@ except ImportError:
     pass
 
 from .cons import backend, contractor, dtypestr, npdtype, rdtypestr
-from .backends import get_backend  # type: ignore
+from .backends import get_backend
 from .utils import is_m1mac, arg_alias
 
 Tensor = Any
@@ -1282,7 +1282,7 @@ try:
             weight = tf.constant(weight, dtype=getattr(tf, dtypestr))
         rsparse = get_backend("numpy").coo_sparse_matrix(
             indices=np.array([[0, 0]], dtype=np.int64),
-            values=np.array([0.0], dtype=getattr(np, dtypestr)),  # type: ignore
+            values=np.array([0.0], dtype=getattr(np, dtypestr)),
             shape=(s, s),
         )
         for i in range(nterms):
@@ -1935,7 +1935,7 @@ def sample2count(
         results = backend.unique_with_counts(sample)  # non-jittable
     else:  # jax specified
         results = backend.unique_with_counts(sample, size=d, fill_value=-1)
-    return results  # type: ignore
+    return results
 
 
 def count_vector2dict(count: Tensor, n: int, key: str = "bin") -> Dict[Any, int]:
@@ -1999,6 +1999,7 @@ def measurement_counts(
     format: str = "count_vector",
     is_prob: bool = False,
     random_generator: Optional[Any] = None,
+    status: Optional[Tensor] = None,
     jittable: bool = False,
 ) -> Any:
     """
@@ -2048,7 +2049,10 @@ def measurement_counts(
         defaults to be False
     :type is_prob: bool
     :param random_generator: random_generator, defaults to None
-    :type random_general: Optional[Any]
+    :type random_generator: Optional[Any]
+    :param status: external randomness given by tensor uniformly from [0, 1],
+        if set, can overwrite random_generator
+    :type status: Optional[Tensor]
     :param jittable: if True, jax backend try using a jittable count, defaults to False
     :type jittable: bool
     :return: The counts for each bit string measured.
@@ -2066,7 +2070,6 @@ def measurement_counts(
         pi = backend.reshape(pi, [-1])
     d = int(backend.shape_tuple(pi)[0])
     n = int(np.log(d) / np.log(2) + 1e-8)
-    drange = backend.arange(d)
     if (counts is None) or counts <= 0:
         if format == "count_vector":
             return pi
@@ -2081,12 +2084,15 @@ def measurement_counts(
                 "unsupported format %s for analytical measurement" % format
             )
     else:
-        if random_generator is None:
-            raw_counts = backend.implicit_randc(drange, shape=counts, p=pi)
-        else:
-            raw_counts = backend.stateful_randc(
-                random_generator, a=drange, shape=counts, p=pi
-            )
+        raw_counts = backend.probability_sample(
+            counts, pi, status=status, g=random_generator
+        )
+        # if random_generator is None:
+        # raw_counts = backend.implicit_randc(drange, shape=counts, p=pi)
+        # else:
+        # raw_counts = backend.stateful_randc(
+        # random_generator, a=drange, shape=counts, p=pi
+        # )
         return sample2all(raw_counts, n, format=format, jittable=jittable)
 
 
@@ -2185,10 +2191,11 @@ def correlation_from_samples(index: Sequence[int], results: Tensor, n: int) -> T
     """
     if len(backend.shape_tuple(results)) == 1:
         results = sample_int2bin(results, n)
-    results = results * 2 - 1
+    results = 1 - results * 2
     r = results[:, index[0]]
     for i in index[1:]:
         r *= results[:, i]
+    r = backend.cast(r, rdtypestr)
     return backend.mean(r)
 
 
