@@ -976,6 +976,8 @@ def test_qiskit2tc():
     qisc.cz(0, 1, ctrl_state=0)
     qisc.cy(0, 1, ctrl_state=0)
     qisc.cx(0, 1, ctrl_state=0)
+    qisc.rxx(0.3, 1, 2)
+    qisc.rzz(-0.8, 2, 0)
     qisc.u(0.3, 0.9, -1.2, 2)
     qisc.rx(np.random.uniform(), 1)
     qisc.ry(np.random.uniform(), 2)
@@ -1219,4 +1221,12 @@ def test_to_openqasm():
     c.cnot(2, 1)
     c.rzz(0, 1, theta=-1.0)
     c.ccx(1, 2, 0)
+    c.u(2, theta=0.5, lbd=1.3)
     print(c.to_openqasm(formatted=True))
+    s = c.to_openqasm()
+    c1 = tc.Circuit.from_openqasm(s)
+    print(c1.draw())
+    np.testing.assert_allclose(c.state(), c1.state())
+    c.to_openqasm(filename="test.qasm")
+    c2 = tc.Circuit.from_openqasm_file("test.qasm")
+    np.testing.assert_allclose(c.state(), c2.state())
